==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/aad/kotlin/inputs/NotificationSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.aad.kotlin.inputs

import com.pulumi.azurenative.aad.inputs.NotificationSettingsArgs.builder
import com.pulumi.azurenative.aad.kotlin.enums.NotifyDcAdmins
import com.pulumi.azurenative.aad.kotlin.enums.NotifyGlobalAdmins
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Settings for notification
 * @property additionalRecipients The list of additional recipients
 * @property notifyDcAdmins Should domain controller admins be notified
 * @property notifyGlobalAdmins Should global admins be notified
 */
public data class NotificationSettingsArgs(
    public val additionalRecipients: Output<List<String>>? = null,
    public val notifyDcAdmins: Output<Either<String, NotifyDcAdmins>>? = null,
    public val notifyGlobalAdmins: Output<Either<String, NotifyGlobalAdmins>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.aad.inputs.NotificationSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.aad.inputs.NotificationSettingsArgs =
        com.pulumi.azurenative.aad.inputs.NotificationSettingsArgs.builder()
            .additionalRecipients(additionalRecipients?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .notifyDcAdmins(
                notifyDcAdmins?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .notifyGlobalAdmins(
                notifyGlobalAdmins?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            ).build()
}

/**
 * Builder for [NotificationSettingsArgs].
 */
@PulumiTagMarker
public class NotificationSettingsArgsBuilder internal constructor() {
    private var additionalRecipients: Output<List<String>>? = null

    private var notifyDcAdmins: Output<Either<String, NotifyDcAdmins>>? = null

    private var notifyGlobalAdmins: Output<Either<String, NotifyGlobalAdmins>>? = null

    /**
     * @param value The list of additional recipients
     */
    @JvmName("svfdtkuggebpdxtd")
    public suspend fun additionalRecipients(`value`: Output<List<String>>) {
        this.additionalRecipients = value
    }

    @JvmName("wyvqjigspqfgwscj")
    public suspend fun additionalRecipients(vararg values: Output<String>) {
        this.additionalRecipients = Output.all(values.asList())
    }

    /**
     * @param values The list of additional recipients
     */
    @JvmName("lmrmmtuujrgbxovr")
    public suspend fun additionalRecipients(values: List<Output<String>>) {
        this.additionalRecipients = Output.all(values)
    }

    /**
     * @param value Should domain controller admins be notified
     */
    @JvmName("qpcxsqvbbunlvfbq")
    public suspend fun notifyDcAdmins(`value`: Output<Either<String, NotifyDcAdmins>>) {
        this.notifyDcAdmins = value
    }

    /**
     * @param value Should global admins be notified
     */
    @JvmName("hpltdhhoqcgtbtxe")
    public suspend fun notifyGlobalAdmins(`value`: Output<Either<String, NotifyGlobalAdmins>>) {
        this.notifyGlobalAdmins = value
    }

    /**
     * @param value The list of additional recipients
     */
    @JvmName("jdukexrbsfctphch")
    public suspend fun additionalRecipients(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.additionalRecipients = mapped
    }

    /**
     * @param values The list of additional recipients
     */
    @JvmName("bcpbdqsdqvdabidq")
    public suspend fun additionalRecipients(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.additionalRecipients = mapped
    }

    /**
     * @param value Should domain controller admins be notified
     */
    @JvmName("boyfhcntpynhevgd")
    public suspend fun notifyDcAdmins(`value`: Either<String, NotifyDcAdmins>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notifyDcAdmins = mapped
    }

    /**
     * @param value Should domain controller admins be notified
     */
    @JvmName("miqbjtgfkxlbqfob")
    public fun notifyDcAdmins(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NotifyDcAdmins>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notifyDcAdmins = mapped
    }

    /**
     * @param value Should domain controller admins be notified
     */
    @JvmName("mfjqhsrvnfxykllj")
    public fun notifyDcAdmins(`value`: NotifyDcAdmins) {
        val toBeMapped = Either.ofRight<String, NotifyDcAdmins>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notifyDcAdmins = mapped
    }

    /**
     * @param value Should global admins be notified
     */
    @JvmName("yqcjsjtuehdhqpvt")
    public suspend fun notifyGlobalAdmins(`value`: Either<String, NotifyGlobalAdmins>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notifyGlobalAdmins = mapped
    }

    /**
     * @param value Should global admins be notified
     */
    @JvmName("eqcckophekiqurri")
    public fun notifyGlobalAdmins(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NotifyGlobalAdmins>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notifyGlobalAdmins = mapped
    }

    /**
     * @param value Should global admins be notified
     */
    @JvmName("iucpcvstmoecubns")
    public fun notifyGlobalAdmins(`value`: NotifyGlobalAdmins) {
        val toBeMapped = Either.ofRight<String, NotifyGlobalAdmins>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notifyGlobalAdmins = mapped
    }

    internal fun build(): NotificationSettingsArgs = NotificationSettingsArgs(
        additionalRecipients = additionalRecipients,
        notifyDcAdmins = notifyDcAdmins,
        notifyGlobalAdmins = notifyGlobalAdmins,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/aad/kotlin/inputs/NotificationSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.aad.kotlin.inputs

import com.pulumi.azurenative.aad.inputs.NotificationSettingsArgs.builder
import com.pulumi.azurenative.aad.kotlin.enums.NotifyDcAdmins
import com.pulumi.azurenative.aad.kotlin.enums.NotifyGlobalAdmins
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Settings for notification
 * @property additionalRecipients The list of additional recipients
 * @property notifyDcAdmins Should domain controller admins be notified
 * @property notifyGlobalAdmins Should global admins be notified
 */
public data class NotificationSettingsArgs(
    public val additionalRecipients: Output<List<String>>? = null,
    public val notifyDcAdmins: Output<Either<String, NotifyDcAdmins>>? = null,
    public val notifyGlobalAdmins: Output<Either<String, NotifyGlobalAdmins>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.aad.inputs.NotificationSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.aad.inputs.NotificationSettingsArgs =
        com.pulumi.azurenative.aad.inputs.NotificationSettingsArgs.builder()
            .additionalRecipients(additionalRecipients?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .notifyDcAdmins(
                notifyDcAdmins?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .notifyGlobalAdmins(
                notifyGlobalAdmins?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            ).build()
}

/**
 * Builder for [NotificationSettingsArgs].
 */
@PulumiTagMarker
public class NotificationSettingsArgsBuilder internal constructor() {
    private var additionalRecipients: Output<List<String>>? = null

    private var notifyDcAdmins: Output<Either<String, NotifyDcAdmins>>? = null

    private var notifyGlobalAdmins: Output<Either<String, NotifyGlobalAdmins>>? = null

    /**
     * @param value The list of additional recipients
     */
    @JvmName("xdaguyufoikpalqf")
    public suspend fun additionalRecipients(`value`: Output<List<String>>) {
        this.additionalRecipients = value
    }

    @JvmName("sgjwpscjcwqypsed")
    public suspend fun additionalRecipients(vararg values: Output<String>) {
        this.additionalRecipients = Output.all(values.asList())
    }

    /**
     * @param values The list of additional recipients
     */
    @JvmName("ccdjebjwvcqkvtam")
    public suspend fun additionalRecipients(values: List<Output<String>>) {
        this.additionalRecipients = Output.all(values)
    }

    /**
     * @param value Should domain controller admins be notified
     */
    @JvmName("rwyiyhcdtimduxtq")
    public suspend fun notifyDcAdmins(`value`: Output<Either<String, NotifyDcAdmins>>) {
        this.notifyDcAdmins = value
    }

    /**
     * @param value Should global admins be notified
     */
    @JvmName("jgbxckbgdnmlsnpi")
    public suspend fun notifyGlobalAdmins(`value`: Output<Either<String, NotifyGlobalAdmins>>) {
        this.notifyGlobalAdmins = value
    }

    /**
     * @param value The list of additional recipients
     */
    @JvmName("vdwvneqgeyixwsij")
    public suspend fun additionalRecipients(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.additionalRecipients = mapped
    }

    /**
     * @param values The list of additional recipients
     */
    @JvmName("bsxgvmhmavamdjuy")
    public suspend fun additionalRecipients(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.additionalRecipients = mapped
    }

    /**
     * @param value Should domain controller admins be notified
     */
    @JvmName("qidhjvtaqqalowgt")
    public suspend fun notifyDcAdmins(`value`: Either<String, NotifyDcAdmins>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notifyDcAdmins = mapped
    }

    /**
     * @param value Should domain controller admins be notified
     */
    @JvmName("jwlupvxtkfhirvnf")
    public fun notifyDcAdmins(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NotifyDcAdmins>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notifyDcAdmins = mapped
    }

    /**
     * @param value Should domain controller admins be notified
     */
    @JvmName("oygcmaqifowogspa")
    public fun notifyDcAdmins(`value`: NotifyDcAdmins) {
        val toBeMapped = Either.ofRight<String, NotifyDcAdmins>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notifyDcAdmins = mapped
    }

    /**
     * @param value Should global admins be notified
     */
    @JvmName("waovaqcdkmaxxrxi")
    public suspend fun notifyGlobalAdmins(`value`: Either<String, NotifyGlobalAdmins>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notifyGlobalAdmins = mapped
    }

    /**
     * @param value Should global admins be notified
     */
    @JvmName("uvjbttifbhuugnox")
    public fun notifyGlobalAdmins(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NotifyGlobalAdmins>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notifyGlobalAdmins = mapped
    }

    /**
     * @param value Should global admins be notified
     */
    @JvmName("gxbwblmlhjhttshp")
    public fun notifyGlobalAdmins(`value`: NotifyGlobalAdmins) {
        val toBeMapped = Either.ofRight<String, NotifyGlobalAdmins>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notifyGlobalAdmins = mapped
    }

    internal fun build(): NotificationSettingsArgs = NotificationSettingsArgs(
        additionalRecipients = additionalRecipients,
        notifyDcAdmins = notifyDcAdmins,
        notifyGlobalAdmins = notifyGlobalAdmins,
    )
}
